@@ -11,6 +11,12 @@ class TestMongoPubSub(unittest.TestCase):
         subscriber = self.pubsub.subscribe('a_chan')
         assert isinstance(subscriber, MongoSubscriber)
 
+    def test_iteration_protocol(self):
+        subscriber = self.pubsub.subscribe('a_chan')
+        self.pubsub.publish('a_chan', 'hello world!')
+        subscriber = iter(subscriber)
+        assert next(subscriber) == 'hello world!'
+
     def test_pubsub(self):
         subscriber = self.pubsub.subscribe('a_chan')
         self.pubsub.publish('a_chan', 'hello world!')
